@@ -155,14 +155,25 @@ extern int cmd_rolleval;
 extern int cmd_calc;
 extern int cmd_count;
 
+int cmplist(const void *p1, const void *p2) {
+	return ((struct val_list*)p1)->values[0] 
+        - ((struct val_list*)p2)->values[0];
+}
+
+/*
+XXX use qsort from libc, but for some reason this segfaults
+void list_quicksort(struct val_list **data, int start, int end) {
+	qsort(&data[start], end-start+1, sizeof(struct val_list*), cmplist);
+}*/
+
 void list_quicksort(struct val_list **data, int start, int end) {
 	if (end > start) {
 		int i=start-1;
 		int j = end;
 		struct val_list *t;
 		for(;;) {
-			while(data[++i]->values[0] < data[end]->values[0]);
-			while(data[--j >= 0 ? j : end]->values[0] > data[end]->values[0]);
+            while(cmplist(data[++i], data[end]) < 0);
+            while(cmplist(data[--j >= 0 ? j : end], data[end]) > 0);
 			if (i>=j)
 				break;
 			t = data[i];
@@ -180,15 +191,16 @@ void list_quicksort(struct val_list **data, int start, int end) {
 }
 
 struct val_list *list_sort(struct val_list *list) {
+	int count = 0;
 	struct val_list *cl = list;
 	// count the list
-	int count = 0;
 	while (cl) {
 		count++;
 		cl = cl->next;
 	}
 	// create an array
-	struct val_list **hash = (struct val_list**)malloc(sizeof(struct val_list*) * count);
+	struct val_list **hash = (struct val_list**)malloc(
+        sizeof(struct val_list*) * count);
 	int i = 0;
 	cl = list;
 	while (cl) {
@@ -229,14 +241,14 @@ struct val_list *list_sort(struct val_list *list) {
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 76 "par.y"
+#line 88 "par.y"
 {
 	int ival;
 	char *tval;
 	expression *expr;
 }
 /* Line 187 of yacc.c.  */
-#line 240 "par.c"
+#line 252 "par.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -249,7 +261,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 253 "par.c"
+#line 265 "par.c"
 
 #ifdef short
 # undef short
@@ -563,15 +575,15 @@ static const yytype_int8 yyrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const yytype_uint8 yyrline[] =
+static const yytype_uint16 yyrline[] =
 {
-       0,   105,   105,   106,   107,   110,   177,   178,   181,   182,
-     183,   184,   185,   186,   187,   188,   189,   190,   191,   192,
-     193,   194,   195,   198,   199,   200,   201,   202,   203,   204,
-     205,   206,   207,   208,   209,   210,   213,   214,   215,   216,
-     217,   218,   219,   220,   221,   222,   223,   224,   225,   226,
-     227,   228,   229,   230,   231,   232,   233,   234,   235,   236,
-     237,   238,   239,   240,   241,   242
+       0,   117,   117,   118,   119,   122,   193,   194,   197,   198,
+     199,   200,   201,   202,   203,   204,   205,   206,   207,   208,
+     209,   210,   211,   214,   215,   216,   217,   218,   219,   220,
+     221,   222,   223,   224,   225,   226,   229,   230,   231,   232,
+     233,   234,   235,   236,   237,   238,   239,   240,   241,   242,
+     243,   244,   245,   246,   247,   248,   249,   250,   251,   252,
+     253,   254,   255,   256,   257,   258
 };
 #endif
 
@@ -1607,7 +1619,7 @@ yyreduce:
   switch (yyn)
     {
         case 5:
-#line 110 "par.y"
+#line 122 "par.y"
     { 
 		if (cmd_parse_tree) {
 			printtree((yyvsp[(1) - (1)].expr), 0); 
@@ -1625,17 +1637,18 @@ yyreduce:
 		}
 		if (cmd_calc) {
 			struct symtab *st = NULL;
+            (yyvsp[(1) - (1)].expr) = optimize((yyvsp[(1) - (1)].expr));
 			set_symtab((yyvsp[(1) - (1)].expr), st);
 			// we can use agnostic here as we are getting a scalar anyway.
 			set_ordering((yyvsp[(1) - (1)].expr), agnostic);
 			struct val_list *vl = eval((yyvsp[(1) - (1)].expr));
-			struct val_list *cl = vl;
-			cl = list_sort(cl);
+			struct val_list *cl = vl = list_sort(vl);
 			while (cl) {
 				if (cl->count != 1) {
 					yyerror("result is not scalar");
 					break;
 				}
+                // XXX make output resolution configurable
 				printf("%3i\t%0.6f\t\n", cl->values[0], cl->prob);
 				cl = cl->next;
 			}
@@ -1668,316 +1681,319 @@ yyreduce:
 				float fprob;
 				fprob = 1.0*cl->prob;
 				fprob /= sum;
+                // XXX make output resolution configurable
 				printf("%3i\t%0.6f\n", cl->value, fprob);
+				struct result_node *old = cl;
 				cl = cl->next;
+				free(old);
 			}
 		}
-	}
+	;}
     break;
 
   case 6:
-#line 177 "par.y"
-    { (yyval.expr) = (yyvsp[(1) - (1)].expr); }
+#line 193 "par.y"
+    { (yyval.expr) = (yyvsp[(1) - (1)].expr); ;}
     break;
 
   case 7:
-#line 178 "par.y"
-    { (yyval.expr) = (yyvsp[(1) - (1)].expr); }
+#line 194 "par.y"
+    { (yyval.expr) = (yyvsp[(1) - (1)].expr); ;}
     break;
 
   case 8:
-#line 181 "par.y"
-    { (yyval.expr) = number_create((yyvsp[(1) - (1)].ival)); }
+#line 197 "par.y"
+    { (yyval.expr) = number_create((yyvsp[(1) - (1)].ival)); ;}
     break;
 
   case 9:
-#line 182 "par.y"
-    { (yyval.expr) = variable_create((yyvsp[(1) - (1)].tval)); }
+#line 198 "par.y"
+    { (yyval.expr) = variable_create((yyvsp[(1) - (1)].tval)); ;}
     break;
 
   case 10:
-#line 183 "par.y"
-    { (yyval.expr) = (yyvsp[(2) - (3)].expr); }
+#line 199 "par.y"
+    { (yyval.expr) = (yyvsp[(2) - (3)].expr); ;}
     break;
 
   case 11:
-#line 184 "par.y"
-    { (yyval.expr) = negate_create((yyvsp[(2) - (2)].expr)); }
+#line 200 "par.y"
+    { (yyval.expr) = negate_create((yyvsp[(2) - (2)].expr)); ;}
     break;
 
   case 12:
-#line 185 "par.y"
-    { (yyval.expr) = plus_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 201 "par.y"
+    { (yyval.expr) = plus_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 13:
-#line 186 "par.y"
-    { (yyval.expr) = minus_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 202 "par.y"
+    { (yyval.expr) = minus_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 14:
-#line 187 "par.y"
-    { (yyval.expr) = multi_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 203 "par.y"
+    { (yyval.expr) = multi_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 15:
-#line 188 "par.y"
-    { (yyval.expr) = divi_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 204 "par.y"
+    { (yyval.expr) = divi_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 16:
-#line 189 "par.y"
-    { (yyval.expr) = mod_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 205 "par.y"
+    { (yyval.expr) = mod_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 17:
-#line 190 "par.y"
-    { (yyval.expr) = expo_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 206 "par.y"
+    { (yyval.expr) = expo_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 18:
-#line 191 "par.y"
-    { (yyval.expr) = scat_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 207 "par.y"
+    { (yyval.expr) = scat_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 19:
-#line 192 "par.y"
-    { (yyval.expr) = dice_create((yyvsp[(2) - (2)].expr)); }
+#line 208 "par.y"
+    { (yyval.expr) = dice_create((yyvsp[(2) - (2)].expr)); ;}
     break;
 
   case 20:
-#line 193 "par.y"
-    { (yyval.expr) = sum_create((yyvsp[(2) - (2)].expr)); }
+#line 209 "par.y"
+    { (yyval.expr) = sum_create((yyvsp[(2) - (2)].expr)); ;}
     break;
 
   case 21:
-#line 194 "par.y"
-    { (yyval.expr) = prod_create((yyvsp[(2) - (2)].expr)); }
+#line 210 "par.y"
+    { (yyval.expr) = prod_create((yyvsp[(2) - (2)].expr)); ;}
     break;
 
   case 22:
-#line 195 "par.y"
-    { (yyval.expr) = count_create((yyvsp[(2) - (2)].expr)); }
+#line 211 "par.y"
+    { (yyval.expr) = count_create((yyvsp[(2) - (2)].expr)); ;}
     break;
 
   case 23:
-#line 198 "par.y"
-    { (yyval.expr) = rep_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 214 "par.y"
+    { (yyval.expr) = rep_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 24:
-#line 199 "par.y"
-    { (yyval.expr) = (yyvsp[(2) - (3)].expr); }
+#line 215 "par.y"
+    { (yyval.expr) = (yyvsp[(2) - (3)].expr); ;}
     break;
 
   case 25:
-#line 200 "par.y"
-    { (yyval.expr) = elist_create(); }
+#line 216 "par.y"
+    { (yyval.expr) = elist_create(); ;}
     break;
 
   case 26:
-#line 201 "par.y"
-    { (yyval.expr) = range_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 217 "par.y"
+    { (yyval.expr) = range_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 27:
-#line 202 "par.y"
-    { (yyval.expr) = lcat_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); }
+#line 218 "par.y"
+    { (yyval.expr) = lcat_create((yyvsp[(1) - (3)].expr), (yyvsp[(3) - (3)].expr)); ;}
     break;
 
   case 28:
-#line 203 "par.y"
-    { (yyval.expr) = perm_create((yyvsp[(2) - (2)].expr)); }
+#line 219 "par.y"
+    { (yyval.expr) = perm_create((yyvsp[(2) - (2)].expr)); ;}
     break;
 
   case 29:
-#line 204 "par.y"
-    { (yyval.expr) = sort_create((yyvsp[(2) - (2)].expr)); }
+#line 220 "par.y"
+    { (yyval.expr) = sort_create((yyvsp[(2) - (2)].expr)); ;}
     break;
 
   case 30:
-#line 205 "par.y"
-    { (yyval.expr) = rev_create((yyvsp[(2) - (2)].expr)); }
+#line 221 "par.y"
+    { (yyval.expr) = rev_create((yyvsp[(2) - (2)].expr)); ;}
     break;
 
   case 31:
-#line 206 "par.y"
-    { (yyval.expr) = (yyvsp[(1) - (1)].expr); }
+#line 222 "par.y"
+    { (yyval.expr) = (yyvsp[(1) - (1)].expr); ;}
     break;
 
   case 32:
-#line 207 "par.y"
-    { (yyval.expr) = ifthenelse_create((yyvsp[(2) - (6)].expr), (yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr)); }
+#line 223 "par.y"
+    { (yyval.expr) = ifthenelse_create((yyvsp[(2) - (6)].expr), (yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr)); ;}
     break;
 
   case 33:
-#line 208 "par.y"
-    { (yyval.expr) = let_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); }
+#line 224 "par.y"
+    { (yyval.expr) = let_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); ;}
     break;
 
   case 34:
-#line 209 "par.y"
-    { (yyval.expr) = whiledo_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); }
+#line 225 "par.y"
+    { (yyval.expr) = whiledo_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); ;}
     break;
 
   case 35:
-#line 210 "par.y"
-    { (yyval.expr) = foreach_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); }
+#line 226 "par.y"
+    { (yyval.expr) = foreach_create((yyvsp[(4) - (6)].expr), (yyvsp[(6) - (6)].expr), (yyvsp[(2) - (6)].tval)); ;}
     break;
 
   case 36:
-#line 213 "par.y"
-    { (yyval.expr) = first_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); }
+#line 229 "par.y"
+    { (yyval.expr) = first_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); ;}
     break;
 
   case 37:
-#line 214 "par.y"
-    { (yyval.expr) = first_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); }
+#line 230 "par.y"
+    { (yyval.expr) = first_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); ;}
     break;
 
   case 38:
-#line 215 "par.y"
-    { (yyval.expr) = first_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); }
+#line 231 "par.y"
+    { (yyval.expr) = first_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); ;}
     break;
 
   case 39:
-#line 216 "par.y"
-    { (yyval.expr) = last_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); }
+#line 232 "par.y"
+    { (yyval.expr) = last_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); ;}
     break;
 
   case 40:
-#line 217 "par.y"
-    { (yyval.expr) = last_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); }
+#line 233 "par.y"
+    { (yyval.expr) = last_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); ;}
     break;
 
   case 41:
-#line 218 "par.y"
-    { (yyval.expr) = last_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); }
+#line 234 "par.y"
+    { (yyval.expr) = last_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); ;}
     break;
 
   case 42:
-#line 219 "par.y"
-    { (yyval.expr) = high_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); }
+#line 235 "par.y"
+    { (yyval.expr) = high_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); ;}
     break;
 
   case 43:
-#line 220 "par.y"
-    { (yyval.expr) = high_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); }
+#line 236 "par.y"
+    { (yyval.expr) = high_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); ;}
     break;
 
   case 44:
-#line 221 "par.y"
-    { (yyval.expr) = high_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); }
+#line 237 "par.y"
+    { (yyval.expr) = high_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); ;}
     break;
 
   case 45:
-#line 222 "par.y"
-    { (yyval.expr) = low_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); }
+#line 238 "par.y"
+    { (yyval.expr) = low_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop); ;}
     break;
 
   case 46:
-#line 223 "par.y"
-    { (yyval.expr) = low_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); }
+#line 239 "par.y"
+    { (yyval.expr) = low_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep); ;}
     break;
 
   case 47:
-#line 224 "par.y"
-    { (yyval.expr) = low_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); }
+#line 240 "par.y"
+    { (yyval.expr) = low_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep); ;}
     break;
 
   case 48:
-#line 225 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, eq); }
+#line 241 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, eq); ;}
     break;
 
   case 49:
-#line 226 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, eq); }
+#line 242 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, eq); ;}
     break;
 
   case 50:
-#line 227 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, eq); }
+#line 243 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, eq); ;}
     break;
 
   case 51:
-#line 228 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, ne); }
+#line 244 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, ne); ;}
     break;
 
   case 52:
-#line 229 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, ne); }
+#line 245 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, ne); ;}
     break;
 
   case 53:
-#line 230 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, ne); }
+#line 246 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, ne); ;}
     break;
 
   case 54:
-#line 231 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, gt); }
+#line 247 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, gt); ;}
     break;
 
   case 55:
-#line 232 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, gt); }
+#line 248 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, gt); ;}
     break;
 
   case 56:
-#line 233 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, gt); }
+#line 249 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, gt); ;}
     break;
 
   case 57:
-#line 234 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, lt); }
+#line 250 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, lt); ;}
     break;
 
   case 58:
-#line 235 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, lt); }
+#line 251 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, lt); ;}
     break;
 
   case 59:
-#line 236 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, lt); }
+#line 252 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, lt); ;}
     break;
 
   case 60:
-#line 237 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, ge); }
+#line 253 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, ge); ;}
     break;
 
   case 61:
-#line 238 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, ge); }
+#line 254 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, ge); ;}
     break;
 
   case 62:
-#line 239 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, ge); }
+#line 255 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, ge); ;}
     break;
 
   case 63:
-#line 240 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, le); }
+#line 256 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), drop, le); ;}
     break;
 
   case 64:
-#line 241 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, le); }
+#line 257 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(3) - (4)].expr), (yyvsp[(4) - (4)].expr), keep, le); ;}
     break;
 
   case 65:
-#line 242 "par.y"
-    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, le); }
+#line 258 "par.y"
+    { (yyval.expr) = comparison_create((yyvsp[(2) - (3)].expr), (yyvsp[(3) - (3)].expr), keep, le); ;}
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1981 "par.c"
+#line 1997 "par.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2191,7 +2207,7 @@ yyreturn:
 }
 
 
-#line 244 "par.y"
+#line 260 "par.y"
 
 
 int yyerror(char *s) {
@@ -2199,8 +2215,10 @@ int yyerror(char *s) {
 	return (1);
 }
 
+extern int yylineno;
+
 long yycurrlinenum() {
-	return yyget_lineno();
+	return yylineno;
 }
 
 char *yycurrfilename() {
